Class: Google::Shopping::Merchant::Accounts::V1beta::ShippingSettings
- Inherits:
-
Object
- Object
- Google::Shopping::Merchant::Accounts::V1beta::ShippingSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/shopping/merchant/accounts/v1beta/shippingsettings.rb
Overview
The merchant account's shipping setting.
Instance Attribute Summary collapse
-
#etag ⇒ ::String
Required.
-
#name ⇒ ::String
Identifier.
-
#services ⇒ ::Array<::Google::Shopping::Merchant::Accounts::V1beta::Service>
Optional.
-
#warehouses ⇒ ::Array<::Google::Shopping::Merchant::Accounts::V1beta::Warehouse>
Optional.
Instance Attribute Details
#etag ⇒ ::String
Returns Required. This field is used for avoid async issue. Make sure shipping setting data didn't change between get call and insert call. The user should do following steps:
-
Set etag field as empty string for initial shipping setting creation.
-
After initial creation, call get method to obtain an etag and current shipping setting data before call insert.
-
Modify to wanted shipping setting information.
-
Call insert method with the wanted shipping setting information with the etag obtained from step 2.
-
If shipping setting data changed between step 2 and step 4. Insert request will fail because the etag changes every time the shipping setting data changes. User should repeate step 2-4 with the new etag.
57 58 59 60 |
# File 'proto_docs/google/shopping/merchant/accounts/v1beta/shippingsettings.rb', line 57 class ShippingSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The resource name of the shipping setting.
Format: accounts/{account}/shippingSetting.
57 58 59 60 |
# File 'proto_docs/google/shopping/merchant/accounts/v1beta/shippingsettings.rb', line 57 class ShippingSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#services ⇒ ::Array<::Google::Shopping::Merchant::Accounts::V1beta::Service>
Returns Optional. The target account's list of services.
57 58 59 60 |
# File 'proto_docs/google/shopping/merchant/accounts/v1beta/shippingsettings.rb', line 57 class ShippingSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#warehouses ⇒ ::Array<::Google::Shopping::Merchant::Accounts::V1beta::Warehouse>
Returns Optional. A list of warehouses which can be referred to in services.
57 58 59 60 |
# File 'proto_docs/google/shopping/merchant/accounts/v1beta/shippingsettings.rb', line 57 class ShippingSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |